==> rice-krad-development-tools-2.5.3.1807.0005-kualico-sources.jar: org/kuali/rice/krad/schema/SchemaConverter.java <==
package org.kuali.rice.krad.schema;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class SchemaConverter
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public static final java.lang.String CONVERTED_FILE_PREFIX = "Converted-";
public SchemaConverter
(java.io.File fileToConvert, java.lang.String[] scanPackages, org.kuali.rice.krad.datadictionary.DataDictionary dataDictionary) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  org.apache.log4j.Logger getLOG() { return (org.apache.log4j.Logger)null;}
public static  java.lang.String getBEAN_CLASS_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getBEAN_PARENT_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getBEAN_TAG() { return (java.lang.String)null;}
public static  java.lang.String getBEANS_TAG() { return (java.lang.String)null;}
public static  java.lang.String getCOMP_ID_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getENTRY_TAG() { return (java.lang.String)null;}
public static  java.lang.String getKEY_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getLIST_TAG() { return (java.lang.String)null;}
public static  java.lang.String getMAP_TAG() { return (java.lang.String)null;}
public static  java.lang.String getMERGE_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getNAME_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getNULL_TAG() { return (java.lang.String)null;}
public static  java.lang.String getREF_TAG() { return (java.lang.String)null;}
public static  java.lang.String getINC_TAG() { return (java.lang.String)null;}
public static  java.lang.String getSET_TAG() { return (java.lang.String)null;}
public static  java.lang.String getSPRING_ELEMENT_PREFIX() { return (java.lang.String)null;}
public static  java.lang.String getUTIL_ELEMENT_PREFIX() { return (java.lang.String)null;}
public static  java.lang.String getP_ATTRIBUTE_PREFIX() { return (java.lang.String)null;}
public static  java.lang.String getPROPERTY_TAG() { return (java.lang.String)null;}
public static  java.lang.String getVALUE_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getVALUE_REF_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getSPRING_NAMESPACE() { return (java.lang.String)null;}
public static  java.util.Map<java.lang.String, java.util.Map<java.lang.String, java.lang.String>> getBeanTagMap() { return (java.util.Map<java.lang.String, java.util.Map<java.lang.String, java.lang.String>>)null;}
public static  void setBeanTagMap(java.util.Map<java.lang.String, java.util.Map<java.lang.String, java.lang.String>> value) { }
public static  java.util.Map<java.lang.String, java.lang.String> getParentTagMap() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public static  void setParentTagMap(java.util.Map<java.lang.String, java.lang.String> value) { }
public  org.w3c.dom.Document getConvertedDocument() { return (org.w3c.dom.Document)null;}
public  void setConvertedDocument(org.w3c.dom.Document value) { }
public  boolean getHasUtilNamespace() { return false;}
public  boolean isHasUtilNamespace() { return false;}
public  void setHasUtilNamespace(boolean value) { }
public  java.lang.String[] getScanPackages() { return (java.lang.String[])null;}
public  void setScanPackages(java.lang.String... value) { }
public  org.kuali.rice.krad.datadictionary.DataDictionary getDataDictionary() { return (org.kuali.rice.krad.datadictionary.DataDictionary)null;}
public  void setDataDictionary(org.kuali.rice.krad.datadictionary.DataDictionary value) { }
public  java.lang.Object buildClassBeanTagMapping() { return null;}
public  java.lang.Object convertSpringFile(java.io.File file, java.io.File convertedFile) { return null;}
public  org.w3c.dom.Element convertBeans(org.w3c.dom.Element beans) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertBean(org.w3c.dom.Element bean) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertNonBean(org.w3c.dom.Element element) { return (org.w3c.dom.Element)null;}
public  java.lang.String findCustomTagName(org.w3c.dom.Element bean) { return (java.lang.String)null;}
public  java.lang.String getCustomTagByClassName(java.lang.String className) { return (java.lang.String)null;}
public  java.lang.String getCustomTagByParent(java.lang.String parent) { return (java.lang.String)null;}
public  org.w3c.dom.Element copyAndPrefixSpringBean(org.w3c.dom.Element bean) { return (org.w3c.dom.Element)null;}
public  java.util.Map<java.lang.String, java.lang.String> createPropertyAttributeMap(java.lang.String tagName) { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public  java.lang.Object convertBeanAttributes(org.w3c.dom.Element bean, org.w3c.dom.Element tagElement, java.util.Map<java.lang.String, java.lang.String> propertyAttributeMap) { return null;}
public  java.lang.Object convertBeanProperties(org.w3c.dom.Element bean, org.w3c.dom.Element tagElement, java.util.Map<java.lang.String, java.lang.String> propertyAttributeMap) { return null;}
public  org.kuali.rice.krad.datadictionary.parse.BeanTagAttribute.AttributeType inferTypeFromContents(org.w3c.dom.Element propertyElement) { return (org.kuali.rice.krad.datadictionary.parse.BeanTagAttribute.AttributeType)null;}
public  java.lang.String parseSingleValue(org.w3c.dom.Element property) { return (java.lang.String)null;}
public  org.w3c.dom.Element convertBeanValue(org.w3c.dom.Element propertyElement, java.lang.String propertyName, boolean byType) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertListValue(org.w3c.dom.Element tagElement, org.w3c.dom.Element property, java.lang.String propertyName) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertListElement(org.w3c.dom.Element listElement) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertSetValue(org.w3c.dom.Element property, java.lang.String propertyName) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertMapValue(org.w3c.dom.Element tagElement, org.w3c.dom.Element property, java.lang.String propertyName) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertMapElement(org.w3c.dom.Element mapElement) { return (org.w3c.dom.Element)null;}
public  java.lang.Object writeDocument(java.io.File file) { return null;}
}

==> rice-krad-development-tools-2.5.3.1809.0004-kualico-sources.jar: org/kuali/rice/krad/schema/SchemaConverter.java <==
package org.kuali.rice.krad.schema;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class SchemaConverter
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public static final java.lang.String CONVERTED_FILE_PREFIX = "Converted-";
public SchemaConverter
(java.io.File fileToConvert, java.lang.String[] scanPackages, org.kuali.rice.krad.datadictionary.DataDictionary dataDictionary) {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  org.apache.logging.log4j.Logger getLOG() { return (org.apache.logging.log4j.Logger)null;}
public static  java.lang.String getBEAN_CLASS_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getBEAN_PARENT_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getBEAN_TAG() { return (java.lang.String)null;}
public static  java.lang.String getBEANS_TAG() { return (java.lang.String)null;}
public static  java.lang.String getCOMP_ID_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getENTRY_TAG() { return (java.lang.String)null;}
public static  java.lang.String getKEY_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getLIST_TAG() { return (java.lang.String)null;}
public static  java.lang.String getMAP_TAG() { return (java.lang.String)null;}
public static  java.lang.String getMERGE_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getNAME_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getNULL_TAG() { return (java.lang.String)null;}
public static  java.lang.String getREF_TAG() { return (java.lang.String)null;}
public static  java.lang.String getINC_TAG() { return (java.lang.String)null;}
public static  java.lang.String getSET_TAG() { return (java.lang.String)null;}
public static  java.lang.String getSPRING_ELEMENT_PREFIX() { return (java.lang.String)null;}
public static  java.lang.String getUTIL_ELEMENT_PREFIX() { return (java.lang.String)null;}
public static  java.lang.String getP_ATTRIBUTE_PREFIX() { return (java.lang.String)null;}
public static  java.lang.String getPROPERTY_TAG() { return (java.lang.String)null;}
public static  java.lang.String getVALUE_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getVALUE_REF_ATTRIBUTE() { return (java.lang.String)null;}
public static  java.lang.String getSPRING_NAMESPACE() { return (java.lang.String)null;}
public static  java.util.Map<java.lang.String, java.util.Map<java.lang.String, java.lang.String>> getBeanTagMap() { return (java.util.Map<java.lang.String, java.util.Map<java.lang.String, java.lang.String>>)null;}
public static  void setBeanTagMap(java.util.Map<java.lang.String, java.util.Map<java.lang.String, java.lang.String>> value) { }
public static  java.util.Map<java.lang.String, java.lang.String> getParentTagMap() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public static  void setParentTagMap(java.util.Map<java.lang.String, java.lang.String> value) { }
public  org.w3c.dom.Document getConvertedDocument() { return (org.w3c.dom.Document)null;}
public  void setConvertedDocument(org.w3c.dom.Document value) { }
public  boolean getHasUtilNamespace() { return false;}
public  boolean isHasUtilNamespace() { return false;}
public  void setHasUtilNamespace(boolean value) { }
public  java.lang.String[] getScanPackages() { return (java.lang.String[])null;}
public  void setScanPackages(java.lang.String... value) { }
public  org.kuali.rice.krad.datadictionary.DataDictionary getDataDictionary() { return (org.kuali.rice.krad.datadictionary.DataDictionary)null;}
public  void setDataDictionary(org.kuali.rice.krad.datadictionary.DataDictionary value) { }
public  java.lang.Object buildClassBeanTagMapping() { return null;}
public  java.lang.Object convertSpringFile(java.io.File file, java.io.File convertedFile) { return null;}
public  org.w3c.dom.Element convertBeans(org.w3c.dom.Element beans) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertBean(org.w3c.dom.Element bean) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertNonBean(org.w3c.dom.Element element) { return (org.w3c.dom.Element)null;}
public  java.lang.String findCustomTagName(org.w3c.dom.Element bean) { return (java.lang.String)null;}
public  java.lang.String getCustomTagByClassName(java.lang.String className) { return (java.lang.String)null;}
public  java.lang.String getCustomTagByParent(java.lang.String parent) { return (java.lang.String)null;}
public  org.w3c.dom.Element copyAndPrefixSpringBean(org.w3c.dom.Element bean) { return (org.w3c.dom.Element)null;}
public  java.util.Map<java.lang.String, java.lang.String> createPropertyAttributeMap(java.lang.String tagName) { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public  java.lang.Object convertBeanAttributes(org.w3c.dom.Element bean, org.w3c.dom.Element tagElement, java.util.Map<java.lang.String, java.lang.String> propertyAttributeMap) { return null;}
public  java.lang.Object convertBeanProperties(org.w3c.dom.Element bean, org.w3c.dom.Element tagElement, java.util.Map<java.lang.String, java.lang.String> propertyAttributeMap) { return null;}
public  org.kuali.rice.krad.datadictionary.parse.BeanTagAttribute.AttributeType inferTypeFromContents(org.w3c.dom.Element propertyElement) { return (org.kuali.rice.krad.datadictionary.parse.BeanTagAttribute.AttributeType)null;}
public  java.lang.String parseSingleValue(org.w3c.dom.Element property) { return (java.lang.String)null;}
public  org.w3c.dom.Element convertBeanValue(org.w3c.dom.Element propertyElement, java.lang.String propertyName, boolean byType) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertListValue(org.w3c.dom.Element tagElement, org.w3c.dom.Element property, java.lang.String propertyName) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertListElement(org.w3c.dom.Element listElement) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertSetValue(org.w3c.dom.Element property, java.lang.String propertyName) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertMapValue(org.w3c.dom.Element tagElement, org.w3c.dom.Element property, java.lang.String propertyName) { return (org.w3c.dom.Element)null;}
public  org.w3c.dom.Element convertMapElement(org.w3c.dom.Element mapElement) { return (org.w3c.dom.Element)null;}
public  java.lang.Object writeDocument(java.io.File file) { return null;}
}
